@@ -1,7 +1,7 @@
 import datetime
 import uuid
 from functools import partial
-from typing import Any, Dict, Union
+from typing import Any, Dict, List, Union
 
 import numpy as np
 import pandas as pd
@@ -36,7 +36,6 @@ class DatapackageBase:
 
     def __init__(self):
         self._finalized = False
-        self._cache = {}
         self._modified = set()
 
     def __get_resources(self) -> list:
@@ -159,16 +158,12 @@ class DatapackageBase:
             (data object, metadata dict)
 
         """
-        try:
-            self._cache[name_or_index]
-        except KeyError:
-            index = self._get_index(name_or_index)
+        index = self._get_index(name_or_index)
 
-            if isinstance(self.data[index], (Proxy, partial)):
-                self.data[index] = self.data[index]()
+        if isinstance(self.data[index], (Proxy, partial)):
+            self.data[index] = self.data[index]()
 
-            self._cache[name_or_index] = (self.data[index], self.resources[index])
-        return self._cache[name_or_index]
+        return self.data[index], self.resources[index]
 
     def filter_by_attribute(self, key: str, value: Any) -> "FilteredDatapackage":
         """Create a new ``FilteredDatapackage`` which satisfies the filter ``resource[key] == value``.
@@ -328,7 +323,7 @@ class Datapackage(DatapackageBase):
 
         self.data = []
 
-    def _substitute_interfaces(self) -> None:
+    def _dehydrate_interfaces(self) -> None:
         """Substitute an interface resource with ``UndefinedInterface``, in preparation for finalizing data on disk."""
         interface_indices = [
             index
@@ -339,13 +334,44 @@ class Datapackage(DatapackageBase):
         for index in interface_indices:
             self.data[index] = UndefinedInterface()
 
+    def dehydrated_interfaces(self) -> List[str]:
+        """Return a list of the resource groups which have dehydrated interfaces"""
+        return [
+            obj["group"]
+            for index, obj in enumerate(self.resources)
+            if isinstance(self.data[index], UndefinedInterface)
+        ]
+
+    def rehydrate_interface(
+        self,
+        name_or_index: Union[str, int],
+        resource: Any,
+        initialize_with_config: bool = False,
+    ) -> None:
+        """Substitute the undefined interface in this datapackage with the actual interface resource ``resource``. Loading a datapackage with an interface loads an instance of ``UndefinedInterface``, which should be substituted (rehydrated) with an actual interface instance.
+
+        If ``initialize_with_config`` is true, the ``resource`` is initialized (i.e. ``resource(**config_data)``) with the resource data under the key ``config``. If ``config`` is missing, a ``KeyError`` is raised.
+
+        ``name_or_index`` should be the data source name. If this value is a string and doesn't end with ``.data``, ``.data`` is automatically added.
+
+        """
+        if isinstance(name_or_index, str) and not name_or_index.endswith(".data"):
+            name_or_index += ".data"
+
+        index = self._get_index(name_or_index)
+
+        if initialize_with_config:
+            resource = resource(**self.resources[index]["config"])
+
+        self.data[index] = resource
+
     def finalize_serialization(self) -> None:
         if self._finalized:
             raise Closed("Datapackage already finalized")
         elif isinstance(self.fs, MemoryFS):
             raise ValueError("In-memory file systems can't be serialized")
 
-        self._substitute_interfaces()
+        self._dehydrate_interfaces()
         self._check_length_consistency()
 
         file_writer(
@@ -356,12 +382,6 @@ class Datapackage(DatapackageBase):
         )
         self.fs.close()
 
-    def define_interface_resource(
-        self, name_or_index: Union[str, int], resource: Any
-    ) -> None:
-        """Substitute the undefined interface with ``resource``"""
-        self.data[self._get_index(name_or_index)] = resource
-
     def _prepare_modifications(self) -> None:
         self._check_length_consistency()
 
